-------------------------------------------------------------------------------
-- Filename:     sil00u_core.vhd
-- History:
--   2006-7-14     First Version
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity sil00u_core is
  generic (
    C_CNT_WIDTH       : integer := 22
  );
  port (
     SYS_CLK : in   std_logic;
     SYS_RST : in   std_logic;
     nSW     : in   std_logic_vector(0 to 2);
     nCODE   : in   std_logic_vector(0 to 3);
     seg_in1 : in   std_logic_vector(0 to 3);
     seg_in2 : in   std_logic_vector(0 to 3);
     seg_in3 : in   std_logic_vector(0 to 3);
     le_trig : in   std_logic;
     SEG     : out  std_logic_vector(0 to 7);
     nSEL    : out  std_logic_vector(0 to 2);
     nLE     : out  std_logic_vector(0 to 3);
     sw      : out  std_logic_vector(0 to 2);
     code    : out  std_logic_vector(0 to 3);
     intr    : out  std_logic
  );
end sil00u_core;

architecture imp of sil00u_core is

  signal count    : std_logic_vector(0 to C_CNT_WIDTH-1);
  signal le       : std_logic_vector(0 to 3);
  signal le_t     : std_logic_vector(0 to 3);
  signal seg_data : std_logic_vector(0 to 3);

  component slot_counter
    generic (
      C_CNT_WIDTH : integer := C_CNT_WIDTH
    );
    port (
      SYS_CLK     : in  std_logic;
      SYS_RST     : in  std_logic;
      count       : out std_logic_vector(0 to C_CNT_WIDTH-1)
    );
  end component;

  component le_seq_blink
    port (
      SYS_CLK     : in  std_logic;
      SYS_RST     : in  std_logic;
      le_timing   : in  std_logic;
      le          : out std_logic_vector(0 to 3)
    );
  end component;

  component dynamic_ctrl
    port (
      SYS_CLK     : in  std_logic;
      SYS_RST     : in  std_logic;
      nSEL        : out std_logic_vector(0 to 2);
      seg7_timing : in  std_logic;
      seg_in1     : in  std_logic_vector(0 to 3);
      seg_in2     : in  std_logic_vector(0 to 3);
      seg_in3     : in  std_logic_vector(0 to 3);
      seg_data    : out std_logic_vector(0 to 3)
    );
  end component;

  component seg7_decoder
    port (
      SEG         : out std_logic_vector(0 to 7);
      seg_data    : in  std_logic_vector(0 to 3)
    );
  end component;

begin

  slot_counter_0 : slot_counter
    port map (
      SYS_CLK     => SYS_CLK,
      SYS_RST     => SYS_RST,
      count       => count
    );

  le_seq_blink_0 : le_seq_blink
    port map (
      SYS_CLK     => SYS_CLK,
      SYS_RST     => SYS_RST,
      le          => le,
      le_timing   => count(0)
    );

  dynamic_ctrl_0 : dynamic_ctrl
    port map (
      SYS_CLK     => SYS_CLK,
      SYS_RST     => SYS_RST,
      nSEL        => nSEL,
      seg7_timing => count(7),
      seg_in1     => seg_in1,
      seg_in2     => seg_in2,
      seg_in3     => seg_in3,
      seg_data    => seg_data
    );

  seg7_decoder_0 : seg7_decoder
    port map (
      SEG         => SEG,
      seg_data    => seg_data
    );

  le_t <= le and "1111" when le_trig = '1' else "0000";
  nLE  <= not le_t;
  sw   <= not nSW;
  code <= not nCODE;
  intr <= count(3);

end imp;
